<script>import { get_current_component } from 'svelte/internal';
import { createEventForwarder, useActions } from '../../internal';
import { randomID } from '../../styles';
import { Input } from '../Input';
import { InputWrapper } from '../InputWrapper';
import { ActionIcon } from '../ActionIcon';
import PasswordToggleIcon from './PasswordToggleIcon.svelte';
import { getButtonSize, getIconSize, getRightSectionWidth } from './PasswordInput.styles';
export let use = [], element = undefined, className = '', override = {}, label = '', description = null, error = null, required = false, disabled = false, labelProps = {}, descriptionProps = {}, errorProps = {}, invalid = false, id = randomID('password-input'), labelElement = 'label', size = 'sm', radius = 'sm', value = '', placeholder = '', toggleTabIndex = -1, visibilityToggleLabel = undefined, visible = undefined, onVisibilityChange = undefined, defaultVisible = undefined;
export { className as class };
let uncontrolledVisible = defaultVisible !== undefined ? defaultVisible : false;
/** An action that forwards inner dom node events from parent component */
const forwardEvents = createEventForwarder(get_current_component());
$: _invalid = invalid || !!error;
$: _visible = visible === undefined ? uncontrolledVisible : visible;
const toggleVisibility = () => {
    if (visible === undefined) {
        uncontrolledVisible = !_visible;
    }
    onVisibilityChange?.(!_visible);
};
</script>

<!--
@component

Password input with visibility toggle

@see https://svelteui.dev/core/password-input
@example
    ```tsx
    <PasswordInput
      label='Password'
      description="Make sure it's very strong"
      required
    />
    ```
-->

<InputWrapper
	bind:element
	class={className}
	{override}
	{label}
	{description}
	{error}
	{required}
	{labelProps}
	{descriptionProps}
	{errorProps}
	{id}
	{labelElement}
	{size}
>
	<Input
		bind:value
		{required}
		{size}
		{id}
		{placeholder}
		{radius}
		rightSectionWidth={getRightSectionWidth(size)}
		{disabled}
		{...$$restProps}
		use={[forwardEvents, [useActions, use]]}
		invalid={_invalid}
		showRightSection
		type={_visible ? 'text' : 'password'}
	>
		<svelte:fragment slot="rightSection">
			{#if !disabled}
				<ActionIcon
					tabindex={toggleTabIndex}
					{radius}
					size={getButtonSize(size)}
					aria-hidden={!visibilityToggleLabel}
					aria-label={visibilityToggleLabel}
					on:click={toggleVisibility}
				>
					<slot name="visibilityToggleIcon" visible={_visible}>
						<PasswordToggleIcon reveal={_visible} size={getIconSize(size)} />
					</slot>
				</ActionIcon>
			{/if}
		</svelte:fragment>
	</Input>
</InputWrapper>
